/*
 *  Copyright 2009 Heinrich Schuchardt.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */
package de.xypron.statistics;

/**
 * Distribution.
 */
public interface Distribution {
    
    /**
     * Safety factor for order rate service level.
     * @param serviceLevel order rate service level
     * @return safety factor
     * @throws Exception exception
     */
    double alphaSafetyFactor(double serviceLevel)
            throws Exception;

    /**
     * Order rate service level for safety factor.
     * @param safetyFactor multiple of standard deviation
     * @return service level
     * @throws Exception exception
     */
    double alphaServiceLevel(double safetyFactor)
            throws Exception;

    /**
     * Safety factor for fill rate service level.
     * @param serviceLevel fill rate service level
     * @return safety factor
     * @throws Exception exception
     */
    double betaSafetyFactor(double serviceLevel)
            throws Exception;

    /**
     * Fill rate service level for safety factor.
     * @param safetyFactor multiple of standard deviation
     * @return service level
     * @throws Exception exception
     */
    double betaServiceLevel(double safetyFactor)
            throws Exception;

    /**
     * Get mean.
     * @return mean
     */
    double getMean();

    /**
     * Get standard deviation.
     * @return standard deviation
     */
    double getStandardDeviation();

    /**
     * Random value.
     * @return random value
     * @throws Exception exception
     */
    double randomValue()
            throws Exception;
}
